pub fn parse_source(source: &str) -> (Program, DiagnosticBag)Expand description
Lex and parse a source string, returning the AST and combined diagnostics.
pub fn parse_source(source: &str) -> (Program, DiagnosticBag)Lex and parse a source string, returning the AST and combined diagnostics.